#
# spec file for package debhelper
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           debhelper
Version:        13.24.1
Release:        1.1
Summary:        Helper programs for debian/rules
License:        GPL-2.0-or-later
Group:          Development/Tools/Building
URL:            https://salsa.debian.org/debian/debhelper
Source0:        https://salsa.debian.org/debian/debhelper/-/archive/debian/%{version}/%{name}-debian-%{version}.tar.gz
# PATCH-FIX-UPSTREAM not build translated-manpages.
Patch0:         debhelper-no-localized-manpages.patch
# PATCH-FIX-UPSTREAM remove --utf8 since we only build En manpages.
Patch1:         debhelper-pod2man-no-utf8.patch
# PATCH-FIX-UPSTREAM debhelper-fix-perl-version-requirement.patch https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=1001403
Patch2:         debhelper-fix-perl-version-requirement.patch
BuildRequires:  dpkg-devel >= 1.18
BuildRequires:  perl-Test-Pod
Requires:       dh-autoreconf >= 17
Requires:       dpkg >= 1.18
Requires:       strip-nondeterminism
Provides:       deb:%{_bindir}/dh_install
BuildArch:      noarch
%if 0%{?suse_version}
Requires:       perl = %{perl_version}
%endif

%description
A collection of programs that can be used in a debian/rules file to
automate common tasks related to building debian packages. Programs
are included to install various files into your package, compress
files, fix file permissions, integrate your package with the debian
menu system, debconf, doc-base, etc. Most debian packages use debhelper
as part of their build process.

%prep
%setup -q -n %{name}-debian-%{version}

%patch -P 0 -p1
%if 0%{?suse_version} && 0%{?suse_version} < 1130
%patch -P 1 -p1
%endif
%if 0%{?suse_version} < 1600
%patch -P 2 -p0
%endif

%build
%make_build VERSION='%{version}'

%check
%make_build test

%install
%make_install

# man pages:
install -d -m 755 %{buildroot}%{_mandir}/man1
install -d -m 755 %{buildroot}%{_mandir}/man7
install -m 644 *.1 %{buildroot}%{_mandir}/man1
install -m 644 debhelper.7 %{buildroot}%{_mandir}/man7

%files
%doc doc/* examples/* debian/changelog debian/copyright
%{_mandir}/man*/*
%{_bindir}/*
%{_datadir}/debhelper
%{perl_vendorlib}/Debian

%changelog
* Mon Jan 20 2025 Jan Baier <jbaier@suse.com>
- update to 13.24.1
  * Fix regression when running 'meson test' (Closes: #1093436)
  * Add CHANGELOG.org as a supported type of changelog (Closes: #1090956)
  * Update dh_installchangelogs doc regarding support for org mode
  * autoscripts: Assume DPKG_ROOT is set but possibly empty
  * Update German translation of manpages (Closes: #1091005)
  * debhelper-compat-upgrade-checklist.pod: Fix typo
  * meson.pm: pass --verbose to meson test (Closes: #1090846)
  * dh_installsystemd: Respect -n/--no-scripts.
* Fri Jan  3 2025 Jan Baier <jbaier@suse.com>
- update to 13.23:
  * makefile.pm: Preserve return value from `sub install`
  * Bring back the python-distutils build-system. It is clearly
    used given removing it caused 200+ FTBFS bugs. Hoever, it is
    also clearly not used (becuase using it would cause FTBFS
    bugs). Instead packages seem to just override all the
    `dh_auto_*` commands and what breaks with the full removal
    is that `dh` cannot find the build system.
    (Reopens: #1089715)
  * dh_installlog{check,rotate}: Re-added `named` `pkgfile`s in
    compat 14+
  * Dh_Lib.pm: Recognize `!=` substvars.
    Thanks to Guillem Jover <guillem@debian.org>
  * Revert "dh_installsysusers: Temporarily add opensysusers
    alternative". The work around is no longer needed. Thanks
    to Samuel Thibault <sthibault@debian.org>.
  * Fix some typos and formatting issues in man pages.
    Thanks to Christoph Brinkhaus <c.brinkhaus@t-online.de>
    (Closes: #1083170)
  * Fix typo of `dh_gencontrol` in man page
  * Remove the defunct python-distutils build-system retroactively.
    Thanks to Colin Watson <cjwatson@debian.org> (Closes: #1089715)
  * dh_fixperms: Remove `exec` bit from files in `/usr/share/themes`
  * Replace `dh-buildinfo` without the `dh_buildinfo` to ease transition.
    As requested in #1068809, `debhelper` will temporarily provide
    `dh-buildinfo` with relevant `Conflicts` and `Replaces` to ensure
    apt can find a solution. The provides is only on a metadata level,
    since most packages no longer use `dh_buildinfo` directly or cope
    gracefully with its removal. A few packages are expected to break,
    which will be cleaned up by people who volunteered in #1068809.
    If your package starts to FTBFS as a consequence of this change,
    please remove the call to `dh_buildinfo`.
    See: #1068809
  * dh_auto_install: Ensure sane minimum mode in destdir [c14]
    (Closes: #1082724)
  * Update German translation of man pages (Closes: #1083169)
* Mon Aug 26 2024 Jan Baier <jbaier@suse.com>
- update to 13.20:
  * dh_installsysusers: Temporarily add opensysusers alternative.
    (See #1076045)
* Mon Aug 19 2024 Jan Baier <jbaier@suse.com>
- update to 13.19:
  * Fix regression in pkgfile where compat 14 semantics were always active.
    Thanks to Salvatore Bonaccorso <carnil@debian.org>
  * dh_lintian: Reject architecture specific overrides files for M-A: same [c14]
    Thanks to Salvatore Bonaccorso <carnil@debian.org> (Closes: #1078830)
  * perl_makemaker: Fix missing import that broke cross-builds.
    Thanks to Helmut Grohne <helmut@subdivi.de> (Closes: #1078707)
  * perl-build: Set PKG_CONFIG during cross builds like perl-makemaker.
    Thanks to gregor herrmann <gregoa@debian.org>
  * Update on Portuguese translation of man pages
  * Reorder default sequence around dh_fixperms and nearby tools in
    compat 14. (Closes: #981783, #982457). This should also avoid
    future issues like LP#1928381 where Ubuntu's modifications to
    `dh_strip` cause differences not visible in Debian.
  * dh_assistant: Fix bug the config introspection could be wrong.
  * debhelper-documentation.json: Associate with `substvars` with
    `dh_gencontrol`.
  * Add some config hints to `dh_makeshlibs` and `dh_gencontrol`.
  * Bump Standards-Version to 4.7.0 - no changes required
  * Dh_Lib.pm: Change `pkgfile` lookup to have opt-in features
    rather than always-on in compat 14. Third-party debhelper tools
    should update their `pkgfile` calls if they need `named` or/and
    architecture specifc configuration files.
  * Set PKG_CONFIG when calling Makefile.pl (makemaker) if not already set
  * Make `dh_auto_install --destdir` change a pure compat 14 change.
    Thanks to Jeremy Bícha <jeremy.bicha@canonical.com>.
    (Closes: #1074322)
- enable test suite during build
* Thu Aug  8 2024 Jan Baier <jbaier@suse.com>
- fix perl compatibility for Leap (bsc#1228955)
* Mon Jul 22 2024 Jan Baier <jbaier@suse.com>
- update to 13.16:
  * dh_assistant: Clearly mark unsafe commands
  * d/changelog: Fix typos in historical entries
  * Migrate to `X-Style: black`
  * dh_assistant.1: Improve documentation and command tagging
  * Improve wording of several man pages.
    Thanks to Christoph Brinkhaus <c.brinkhaus@t-online.de> (Closes: #1069176)
  * Require a package prefix with `--name` in c15 (warning in c14)
  * dh_assistant: Report data about disabled commands in some subcommands.
    This breaks a small subset of the `dh-debputy` features and a related
    `Breaks` has been added.
  * Fix a "comat" -> "compat" typo in _load_compat_info()
  * dh_installtmpfiles: implement remove on removal, purge on purge
  * Update German translation of man pages (Closes: #1069176)
* Fri May  3 2024 Jan Baier <jbaier@suse.com>
- update to 13.15.3:
  * debhelper-compat-upgrade-checklist.pod: Fix repeated substvar.
    Thanks to Andrey Rakhmatullin
  * debhelper-compat-upgrade-checklist.pod: Add ref to #1067653
  * dh_gencontrol: Gracefully cope with custom substvars and -dbgsym packages
    (Closes: #1067711)
  * upgrade-checklist: Document `dh_installsystemduser` change
    (Closes: #1066025)
  * autopkgtest: Remove reference d/compat triggering perl tests
  * dh_gencontrol: Fix inverted boolean logic causing warnings
  * Dh_Lib.pm: Fix field truncation in compat 14+
    (Closes: #1067508, #1067509)
  * d/changelog: Fix typo of Felix Geyer
  * dh_makeshlibs: Ensure t64:Provides is always provided (but
    sometimes empty)
  * Replace `d/compat` with a `X-DH-Compat` field in compat 14+.
    (Closes: #1021877)
  * Ensure values to --dbg-package and --link-doc are known packages
  * PROGRAMMING.md: Add a note about `dh_assistant`
  * Make it easier to re-bootstrap without `dwz` (and also `man-db`).
    This is a new build profile that build `debhelper` with fewer
    dependencies. Note that this profile causes `debhelper` to produce
    a different result in some cases. Packages built with this minimal
    version of debhelper should be rebuilt when bootstrapping is
    complete.
  * dh_shlibdeps: Use ${shlibs:Pre-Depends} for Essential packages
    in compat 14+.
  * dh_gencontrol: Automatically apply relationship substvars in
    compat 14+
  * Clearly document how to do filtering (which is via dh-exec)
    (Closes: #1065742)
  * Reject debhelper config files without a package prefix for
    multi-binary packages in compat 15. Starting in compat 14, it will
    now trigger a warning to have `debian/install` instead of
    `debian/package.install` when `debian/control` contains 2 or more
    binary packages. In compat 15, this is promoted to an error.  The
    main exceptions are files like `debian/changelog`, `debian/NEWS`,
    and `debian/copyright`, which are applied to all packages and can
    still be used without a prefix. (Closes: #1014537)
  * cmake.pm: Pass ASFLAGS as ASMFLAGS to cmake [c14] (Closes: #1036760)
  * meson.pm: Pass --auto-features=enabled in compat 14+
    (Closes: #1030011, #1062508)
  * Dh_Lib.pm: Simplify reset_perm_and_owner so it only works with int
    now. The only misbehaving call-sites where in debhelper itself
    according to codesearch.debian.net and were fixed as well.
  * Dh_Lib.pm: Bump perl version requirement to 5.28 (Closes: #1001403)
  * dh_makeshlibs: Skip directories known not to contain SONAMEs
    (Closes: #1063126)
  * Restructure debhelper upgrade compat checklist for compat 14 in an
    attempt to make it easier for consumers.
  * dh_makeshlibs: Correct the auto-detected package name
  * dh_makeshlibs: Use the "correct" package architecture definition
  * debhelper-documentation.json: The pam change happened in c14
  * dh_assistant: Expose bug#950723 marker in
    list-guessed-dh-config-files
  * dh_installsystemduser: Add missing pkgfiles in DH NOOP promise
  * debhelper-documentation.json: Add dh_installsystemd files
  * debhelper-documentation.json: Add dh_installsystemduser files
  * d/changelog: Fix typo in a previous entry
  * dh_gencontrol: Avoid Static-Built-Using in -dbgsym packages
    (Closes: #1062960)
  * dh_makeshlibs: Improve handling of t64 transition support
  - The presence of the `X-Time64-Compat` now unconditionally
    trigger the `${t64:Provides}` substvar.
  - Auto-detection is now extended to include t64-nss libraries
    (The detection regex is now: `m/^lib.*t64(?:-nss)?$/`)
  - The `${t64:Provides}` substvars now uses `${binary:Version}`
    instead of trying to guess the version. This works better
    for packages that manually set their own version via
    dpkg-gencontrol's -v option.
  * check the dpkg "features" to decide whether to emit t64:Provides
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Feb  5 2024 Jan Baier <jbaier@suse.com>
- update to 13.13:
  * Add `debhelper-documentation` `debputy` plugin. This provides
    `debputy` with some files and file patterns for `debputy`'s
    new `debputy tool-support annotate-debian-directory`.
  * Revert "Dh_Lib.pm: Fix warning from `cp -n`"
    Thanks to Sven Joachim <svenjoac@gmx.de> (Closes: #1061610)
* Mon Feb  5 2024 Jan Baier <jbaier@suse.com>
- update to 13.12:
  * Add support for an 'X-Time64-Compat' field in debian/control to allow
    overriding of the auto-generated Provides: as necessary.
    Closes: #1059941.
  * dh_assistant: Exit with code 2 when unknown hook targets are found
  * dh_assistant: Add the following new subcommands:
  - `supports COMMAND` can be used to programmically check whether
    dh_assistant knows about `COMMAND`. It is a lot better than having
    to check versions or parse `--help` output.
  - `list-commands` can be used to determine all "debhelper commands"
    that will run from a source package (assuming no overrides and
    no add-on adds a non-standard sequence). This command has a
    text and a JSON output.
  - `list-guessed-dh-config-files` can be used to list all
    debhelper config and their related commands. The result
    involves a lot of guess work and will never be 100%% reliable,
    which explains the `guessed` part of the command. The output
    is always JSON.
  - Add `restore-file-on-clean` with all its caveats. Use it with
    care for the few cases where it is useful.  (Closes: #1051184)
  * dh_assistant: Always parse Build-Depends for sequences. This
    would have prevented `detect-unknown-hook-targets` from reporting
    issues about hook targets related to add-ons if they were loaded
    via `Build-Depends`.
  * dh_assistant: `detect-unknown-hook-targets` now continues when
    add-ons loading fails. It will still exit with status 2 by
    default when this occurs as if it found an issue.
  * cmake.pm: Remove compat guard for `-DBUILD_TESTING:BOOL=off`
    on `nocheck`
  * Dh_Lib.pm: Fix warning from `cp -n`
  * qmake6.pm: Add cross-compiling support (Closes: #1059209)
  * Add <pkg.debhelper.nonls> build profile (Closes: #1032816)
* Fri Jan 26 2024 Jan Baier <jbaier@suse.com>
- update to 13.11.10:
  * dh_installsystemduser: fix daemon-reload of user instances
  * dh_clean: Clean __pycache__ (Closes: #1048890)
  * dh_installchangelogs: Generate separate binNMU changelog also
    under --no-trim (Closes: #1059395)
  * dh_assistant: Add filename to `detect-hook-targets`
  * Dh_Lib.pm: Ensure `$_use_color` is always initialized first time
  * dh_assistant: Add detect-unknown-hook-targets subcommand
* Fri Jan  5 2024 Jan Baier <jbaier@suse.com>
- update to 13.11.9:
  * dh_installudev: install into /usr (Closes: #1058791)
  * dh_movetousr: also update links from canonical into aliased
  * buildsystems: add qmake6 variant of the qmake buildsystem (Closes: #1057359)
* Mon Dec  4 2023 Jan Baier <jbaier@suse.com>
- update to 13.11.8:
  * systemd helpers: install units to /usr.
  * Trim NEWS when trimming changelog (Closes: #1021607)
  * dh_makeshlibs: add compatibility Provides: for 64-bit time_t transition.
  * add new helper and addon: movetousr
  * systemd helpers: Support units below /usr (Closes: #1041159)
* Fri Sep  8 2023 Jan Baier <jbaier@suse.com>
- fix initialization of state variables problem (bsc#1215078)
  added debhelper-fix-perl-version-requirement.patch
* Mon Sep  4 2023 Jan Baier <jbaier@suse.com>
- update to 13.11.5:
  * Update Portuguese translation (Américo Monteiro)
    (Closes: #1028159)
  * Update on German translation of pages (Closes: #1028564)
  * Fix minor typo in DEB_BUILD_OPTIONS warning ("and but not" -> "but not")
  * AddonAPI.pm: Correct method name in error message.
    Thanks to wferi@Github
  * dh_missing: Update link to PROGRAMMING.md.gz
  * cmake.pm: set -DBUILD_TESTING=OFF for nocheck builds
  * autoscripts/postinst-init-tmpfiles: do not output to /dev/null to not hide error messages
  * cmake.pm, meson.pm: Set DEB_PYTHON_INSTALL_LAYOUT=deb if not already set
    (Closes: #1043136)
  * buildsystems: Give XDG_RUNTIME_DIR spec-compliant u=rwx,og-rwx permissions
  * meson.pm: Disable Python byte-compilation if the Meson version is new enough
    (Closes: #1042398)
* Thu Jan  5 2023 Dirk Müller <dmueller@suse.com>
- update to 13.11.4:
  * meson.pm: Pass --destdir to `meson install`.  (Closes: #1027014)
  * Dh_Lib.pm: Have addsubstvars check the value for newlines (Closes: #1026014)
  * Stop using (fake)root for mkdirs again.
    Should have been removed as a part of the clean up in the previous
    upload but was overlooked causing breakage in packages still having
    `Rules-Requires-Root: binary-targets`. (Closes: #1026125)
  * PROGRAMMING.md: Fix typos
  * Dh_Lib.pm: Remove unused third parameter from install_dh_config_file
  * makefile.pm: Provide hook for subclasses to reuse cross-build support
  * Dh_Lib.pm: Revert change where `install_{file,prog,lib}` would use chown.
    The problem that prompted this change was not caused by debhelper but
    by fakeroot (#1024544) and the change in debhelper would not even
    function as a work around in this case.  Accordingly, the extra
    complexity is not worth it and has been reverted.
  * Dh_Lib.pm: Fix typo in warning message about dherroron
* Mon Dec 12 2022 Jan Baier <jbaier@suse.com>
- Update to version 13.11.1
  * dh_installchangelogs: Ensure that at least four old entries are preserved
    (Closes: #1021467)
  * meson.pm: Use `meson setup` in the configure step rather than just `meson`.
  * Put newest compat level first in documentation
  * Rename debhelper config files to include package name
  * dh_installdebconf: Fix typo in manual page
  * Dh_Lib.pm: `qx_cmd` support env/chdir changes like `doit` (Closes: #1016354)
  * Remove obsolete compat checks in the code
  * dh_dwz: Ensure dwz multifile is owned by root:root when root should be used
  * dh_builddeb: Always pass `--root-owner-group` to `dpkg-deb` for dbgsym packages.
  * Dh_Lib.pm: Provide `mkdirs` to create (non-package) directories.
  * Dh_Lib.pm: Make `install_dir` chown created directories when root should be
    used for debhelper's own commands.  This fixes #1024261 for packages that only
    use debhelper itself. However, third-party debhelper tools may still cause
    packages with incorrect ownership for now if they are run after `dh_fixperms`
    (or `dh_fixperms` is omitted).
  * Dh_Lib.pm: Ensure `install_{file,prog,lib}` uses chown when root should be used.
    Previously, they would skip the `chown` call and rely on `dh_fixperms`
    or `dpkg-deb` to fix the ownership.  However, that could cause issues
    when the helper was run after `dh_fixperms` and install files that
    `dpkg-deb` would not reset ownership of.
  * Install `installsysusers` sequence (to match the provide).
  * dh_installchangelogs: Trim old Debian changelog entries
    automatically.  Distributions can disable this by using
    `DEB_BUILD_OPTIONS=notrimdch`.
  * dh_installchangelogs.t: Force locale to be `C.UTF-8` to
    avoid generating invalid changelog entries under
    non-default locales.
  * meson.pm: Stop providing `MESON_TESTTHREADS` environment
    variable for the install target.  Said variable only
    applies for testing.
  * cmake.pm: Use `cmake --install` in compat 14.
    (Closes: #1020732)
  * docs/PROGRAMMING{,.md}: Rewrite PROGRAMMING into markdown.
  * dh_installsystemduser: Stop masking user units on package
    removal.  They should never have been masked in the first
    place.  See #1021027.
  * dh_installinit: Remove executable bit of init scripts on
    package removal (via preinst).  Related to #1021027.
  * dh_installsystemd: Stop masking system units on package
    removal.  This is no longer necessary with the init scripts
    getting their exec bit cleared on package removal.
    (Closes: #1021027)
  * Dh_Lib.pm: Add `package_type` as a function (extracted
    from `is_udeb`).
  * Dh_Getopt.pm: Fix duplicated `warning` in output for a
    particular warning.
  * dh_assistant: Provide a new `detect-hook-targets` command.
  * dh: Recommend using `dh_assistant detect-hook-targets` for
    checking whether hook targets are correct.
  * dh: Hoist `nodoc` and `nocheck` from `DEB_BUILD_PROFILES`
    into `DEB_BUILD_OPTIONS` when they are present in the former
    and absent in the latter.  Emit a warning when doing so to
    aid the user, so they know why this does not work when they
    are later building a package that does not use dh.
    (Closes: #979401)
  * dh: Provide a warning when cross building an `nocheck` is
    absent from `DEB_BUILD_OPTIONS` to cross builders, who are
    not experienced with Debian's requirements for
    cross-building.  The warning also recommends activating the
    `cross` build profile and provides a way to disable the
    warning without using `nocheck` (for the special case, where
    people have a system that can run host binaries).
  * Dh_Lib.pm: Fix bug where `addsubstvars` would not respect
    the `--no-act` parameter.
  * dh_perl: For scripts that are detected as perl scripts
    that would trigger a dependency, normalize the shebang line to
    use the same perl as debhelper is run under (/usr/bin/perl
    in Debian, YMMV in derivatives).  (Closes: #904409)
  * dh_assistant: Provide new `log-installed-files` command to
    help users and third-party tools record which files they have
    installed.  Third-party tools should use the
    `--on-behalf-of-cmd` to have their tool name recorded.
    (Closes: #972724)
  * dh_installexamples: Explicitly recommend `examples/*` over
    `examples` as content for the `debian/<pkg>.examples` file
    to avoid the triggering `.../examples/examples` case.
    (Closes: #1000384)
  * debhelper.pod: Clarify the documentation around `-v` +
    `--verbose` vs. `DH_VERBOSE` vs. `DH_QUIET` and `terse`
    from `DEB_BUILD_OPTIONS`.  Notably, clarify that `-v`
    and `DH_VERBOSE` provides the same functionality and
    that they do not cause *all* commands to be shown.
    (Closes: #1002464)
  * Update Portuguese translation (Américo Monteiro)
    (Closes: #1019231)
  * autoscripts/postinst-init-tmpfiles: Re-instate runtime check
    before running `systemd-tmpfiles`. However, explicitly check
    for `systemd-tmpfiles` rather than asserting the system was
    booted by systemd. This resolves #1013969 without requiring
    a strict dependency as originally suggested by Guilhem Moulin
    in #1013969.
  * dh_installtmpfiles: Remove the `systemd | systemd-tmpfiles`
    dependency as it is no longer required.  (Closes: #1017441)
  * dh_installsystemd: Ditto.
  * dh_installinit: Ditto.
  * autoscripts/postinst-init-tmpfiles: Only pass `--root` to systemd
    when `DPKG_ROOT` is present (as `--root=/` is different from
    omitting `--root` entirely).
  * autoscripts/postinst-sysusers: Ditto
* Mon Aug 15 2022 Jan Baier <jbaier@suse.com>
- Update to version 13.9
  * d/control: Provide dh-sequence-installsysusers.
  * debhelper.pod: Add missing word "variables".
  * Dh_Lib.pm: Fix in addsubstvar where a value was added when
    it should not have been.  (Closes: #1015263)
* Thu Aug  4 2022 Jan Baier <jbaier@suse.com>
- Update to version 13.8
  * dh_perl: Fix incorrect binary versioning caused by a regression
    in 13.3.  Thanks to Niko Tyni for reporting the issue.
    (Closes: #997961)
  * d/control: Bump Standards-Version to 4.6.1 - no changes required.
  * root_sequence.pm: Run `dh_installsysusers` before
    `dh_installtmpfiles` (only affects compat 14 or later).  Thanks
    to Nicholas Brown for the suggestion.  (Closes: #1011099)
  * autoscripts/postinst-init-tmpfiles: Remove runtime check on the
    system having systemd as init system.
  * dh_installtmpfiles: Replace runtime check on the system running
    under systemd in generated `postinst` script with a dependency
    on `systemd | systemd-tmpfiles` added to `${misc:Depends}`.
    Thanks to Guilhem Moulin for the suggestion.  (Closes: #1013969)
  * dh_installsystemd: Ditto.
  * dh_installinit: Ditto.
  * debhelper-compat-upgrade-checklist.pod: Correct description for
    the addition of dh_installsysusers in compat 14.
  * meson.pm: Use `meson install` instead of `ninja install` for
    dh_auto_install in compat 14.  Thanks to Andrea Pappacoda for
    the suggestion.  (Closes: #1006805)
  * Dh_Lib.pm: Remove double semi-colon.  (Closes: #1010591)
  * Dh_Lib.pm: _strip_spaces now explicitly returns undef on undef
    argument.
    (Closes: #1010594)
  * cmake.pm: Set FETCHCONTENT_FULLY_DISCONNECTED to true.  This
    ensures that the `FetchContent` module does not attempt to
    use internet connection.
  * debhelper-compat-upgrade-checklist.pod: Update documentation
    for compat 14 change.  (Closes: #1011404)
  * debhelper.pod: Correct link to the new upgrade checklist.
    (Closes: #1012777)
  * dh_installman: Avoid false positive language detection on
    shared libs.
  * Update Portuguese translation (Américo Monteiro)
    (Closes: #1011256)
* Mon May  2 2022 Jan Baier <jbaier@suse.com>
- Update to version 13.7.1
  * debhelper.pod: Fix several typos.  Thanks to Guillem Jover
    for pointing them out and proposing corrections.
  * dh_installalternatives: Correct a file check that caused
    false-positive rejections of valid alternatives files.  Thanks to
    Hiroyuki YAMAMORI for reporting the bug and providing an initial
    patch.  (Closes: #1009844)
* Mon May  2 2022 Jan Baier <jbaier@suse.com>
- Update to version 13.7
  * dh_installalternatives: Improve validation of alternative files to
    catch some "obvious" copy-waste mistakes.
  * dh: Invoke dh_installalternatives after dh_link in compat 14 or
    later. Thanks to Colin Watson for the suggestion.
    (Closes: #1002800)
  * cmake.pm: Drop -DCMAKE_SKIP_RPATH=on in compat v14.  Thanks to
    Vagrant Cascadian for the suggestion and the investigative work on
    this topic.  (Closes: #1004939)
  * debhelper-compat-upgrade-checklist.pod: New file.
  * debhelper.pod: Move list of supported compat levels and the related
    upgrade checklist into debhelper-compat-upgrade-checklist.pod.
    This means you now need `man 7 debhelper-compat-upgrade-checklist`
    to see the upgrade checklist.
  * dh_installdebconf: Support -D/--define command line parameters
    (mirroring those from dh_installdeb).
  * Dh_Lib.pm: Cope with "?=" as assignment operator in substvars files
    to be future proof with (possible) planned addition of "optional
    substvars.  At the moment, debhelper will still always use "=" when
    adding a substvar but it will now preserve "?=" operator if an
    existing substvar is modified.
  * autoconf.pm: Add support for autotest test suites by passing the
    TESTSUITEFLAGS environment variable to `make test`.
  * Rewrite handling of stop services to use the `preinst` when using
  - -no-restart-after-upgrade.  This fixes a regression caused by
    the fix for #989155.  (Closes: #994204)
  * dh_installmenu: Respect DPKG_ROOT when checking for update-menus.
    Note this implementation assumes update-menus is present both
    inside and outside the chroot to activate.  If it is absent on
    either side, the update-menus call is skipped.
  * dh_installsysusers: Invoke systemd-sysusers even when DPKG_ROOT
    is set (relying on `--root`).
  * dh_installpam: In compat 14, install pam snippets into
    `/usr/lib/pam.d` instead of `/etc/pam.d`.  Remember to remove
    (now) obsolete conffiles when you bump to compat 14.
  * debhelper.pod: Correct spelling of DEB_BUILD_MAINT_OPTIONS.
* Mon Jan  3 2022 Jan Baier <jbaier@suse.com>
- Update to version 13.6
  * dh_assistant: Avoid creating `debian/.debhelper` when the
    which-build-system sub command is invoked.  Thanks to
    Jelmer Vernooĳ for spotting that bug.
  * dh_assistant: Add new active-compat-level command, which
    outputs information about which compat level is declared
    and active.  It also tells how the compat level was
    declared.
  * Dh_Lib.pm: Add new function, get_non_binnmu_date_epoch,
    only needed for dh_strip_nondeterminism.
  * dh_installcron: Add support for `cron.yearly` packaging
    file.  Thanks to Martin-Éric Racine for the suggestion.
    (Closes: #1000363)
  * Dh_Lib.pm: Remove support for compat 5 and 6.
  * debhelper.pod,debhelper-obsolete-compat.pod: Update to
    reflect the new status for compat 5 and 6.
  * dh: Add missing _ in execute_after example in POD.
  * dh_compress: Exclude .woff and .woff2 by default.
  * Update Portuguese translation (Américo Monteiro)
    (Closes: #1000719)
* Mon Oct 18 2021 Jan Baier <jbaier@suse.com>
- Update to version 13.5.2
  * dh_installsystemd: Revert change to deploy systemd files into
    usr/lib/systemd.  (Closes: #993316, #993759)
  * dh_installinit: Ditto.
  * dh_systemd_enable: Ditto.
  * dh_systemd_start: Ditto.
  * SequencerUtil.pm: Remove duplicate "-a" option to some commands.
    Thanks to Christoph Berg for reporting the issue.
    (Closes: #971761)
  * dh_installdeb: Revert the change to rewrite `rm_conffiles` into
    `remove-on-upgrade` due to it causing bugs in non-trivial cases.
    (Closes: #994919)
  * dh_installtmpfiles: Add missing option name in POD documentation.
  * cmake.pm: make it possible to override dh provided ctest arguments
  * cmake.pm: Add missing import which broke cmake related builds.
    Thanks to Boyuan Yang for reporting the issue.
    (Closes: #993345)
  * dh_installdeb: Install debian/conffiles in compat 12+ again
    (undoing the compat 12 change saying dh_installdeb would ignore
    this file).  The file can now be using for the activating the
    `remove-on-upgrade` feature from dpkg 1.20.
  * dh_installdeb: Automatically rewrite `rm_conffiles` into the
    new `remove-on-upgrade` feature from dpkg when possible.
  * cmake.pm: Pass `ARGS+=--verbose` to make when running tests
    in the cmake+make variant except when "terse" is in
    DEB_BUILD_OPTIONS.  Thanks to Paul Wise for the suggestion.
    (Closes: #992623)
  * python_support.pm: Remove obsolete dh addon.  It did nothing
    but warn and nothing used it anymore.
  * dh: Document debhelper provided dh addon sequences.
  * single_binary.pm: New dh addon ("single-binary") that explicitly
    activates the "single binary" work flow, where dh_auto_install
    uses debian/<pkg> as default --destdir when there is only a
    single binary package.  It will error out if used in a
    source package building multiple binary packages.
  * dh: Activate "single-binary" addon by default in compat levels
    up to and including compat 14 when the source package only lists
    one binary package in debian/control.  In compat 14, emit a warning
    when this happens implicitly requesting users to explicitly enable
    or disable the addon for single binary source packages to avoid
    surprises in compat 15.
  * dh_auto_install: In compat 15, remove special-case default for
  - -destdir for single binary source packages.  If the previous
    default is desired, please use the "single-binary" dh addon or
    explicitly pass --destdir to dh_auto_install.
    (Closes: #971432)
  * debian/control: Provide dh-sequence-single-binary.
  * debhelper.pod: Document the dh_auto_install will change behaviour
    in compat 15 for single binary packages and dh will warning about
    that in compat 14.
  * dh_assistant: New tool for assisting third-party tools.  At the
    moment, it primarily supports introspection related features but
    will hopefully be extended to support more use cases.
    (Closes: #984900)
* Mon Oct 18 2021 Jan Baier <jbaier@suse.com>
- Update to version 13.4.1
  * autoscripts/*: Replace `which` with `command -v`.
  * dh_installsystemd: Only merge /lib/systemd/system into /usr
    for now.  (Closes: #992554)
  * dh_systemd_enable: Ditto.
  * autoscripts/postinst-init-nostart: Call invoke-rc.d when
    a non-empty DPKG_ROOT is used.  (Closes: #992556)
  * Replace "use v5.28" with "use v5.24" in Dh_Lib.pm.
    The change to "use v5.28" in 13.4 broke the test to distinguish 0755
    from "0755" in the reset_perm_and_owner function, breaking builds.
    Thanks Adrian Bunk and Ansgar for help isolating the problem.
  * debian/changelog: Correct bug number in the 13.4 entry.
  * dh_dwz: run in parallel across packages.  (Closes: !47)
  * Dh_Buildsystems.pm: Add bmake and mkcmake as third-party
    build systems.  (Closes: !46)
  * Dh_Buildsystems.pm: Add golang as a third-party build
    system.  (Closes: #981106)
  * autoscripts/*: Add support for DPKG_ROOT in systemd, tmpusers,
    sysusers and init related snippets.  Based on an initial patch
    from Helmut Grohne.  (Closes: #983566)
  * autoscripts/*: Reorder conditions in some scripts to avoid
    doing a redundant stat call when a script parameter can decide
    to skip it.
  * dh_gconf: Remove the command as it does nothing.
    (Closes: #908845)
  * doc/TODO: Remove reference to dh_gconf.
  * root_sequence.pm: Remove dh_gconf from root sequence and declare
    it as obsolete (causing errors from compat 14 if still referenced
    in hook targets).
  * man/po4a/po4a.cfg: Remove dh_gconf from translations.
  * AddonAPI.pm: The declare_command_obsolete command now accepts an
    "$error_compat" parameter to enable addons to choose which compat
    level that will trigger an error (though it must be minimum 13).
  * doc/PROGRAMMING: Update docs to reflect API change.
  * debhelper.pod: Document that referencing dh_gconf in hook targets
    will cause an error in compat 14.
  * dh_fixperms: Correct permissions of files beneath usr/libexec to
    be executable.  (Closes: #979401)
  * dh_installtmpfiles: Only register tmpfiles ending with ".conf" as
    tmpfiles in /usr/lib/tmpfiles.d and /etc/tmpfiles.d.  This ensures
    that dh_installtmpfiles gracefully copes with e.g. README files
    provided by systemd upstream.  (Closes: #986329)
  * dh_installsystemd: Ditto (but only relevant in compat 12 or
    earlier)
  * cmake.pm: Pass -DCMAKE_FIND_USE_PACKAGE_REGISTRY=OFF to cmake in
    addition to -DCMAKE_FIND_PACKAGE_NO_PACKAGE_REGISTRY=ON as the
    former is intended to replace the latter.  Thanks to Raul Tambre
    for reporting the issue.  (Closes: #988973)
  * Dh_Lib.pm: Bump version requirement to v5.28 to reflect the actual
    requirements (the code was using v5.28 features).  Thanks to
    Sérgio Basto for reporting the issue.
  * dh_missing: Ditto.
  * autoscripts/postinst-init,autoscripts/postinst-systemd-start: Use
    "restart" instead of "start" when starting the services.  This
    ensures a smooth transition from --restart-after-upgrade to
  - -no-restart-after-upgrade in dh_installinit and dh_installsystemd.
    Thanks to Ryan Tandy for reporting the issue.
    (Closes: #989155)
  * dh_installsystemd: Remove usage of autoscripts/postinst-systemd-restart
  * dh_installinit: Remove usage of autoscripts/postinst-init-restart
  * autoscripts/autoscripts/postinst-systemd-restart: Removed.
  * autoscripts/postinst-init-restart: Removed
  * dh_installsystemd: Prefer /usr/lib/systemd/ to /lib/systemd.
    (Closes: #987989)
  * dh_systemd_enable: Ditto.
  * dh_systemd_start: Ditto.
  * dh_installinit: Ditto.
  * dh_installsystemd: Merge /lib/systemd into /usr/lib/systemd if both
    are present in the package staging directory (prefering the latter
    in case of conflicts).  (Closes: #987989)
  * dh_systemd_enable: Ditto.
  * perl_build.pm,perl_makemaker.pm: Make debhelper use the same perl
    as it runs under (via Perl's $^X variable) when invoking the
    upstream build system.  (Closes: !40, #966396)
  * Always generate unique doc-base file names based on package name and
    document ID. (Closes: #980903)
* Tue Mar 16 2021 Jan Baier <jbaier@suse.com>
- Update to version 13.3.4
- Adapt patches to new upstream version:
  * remove debhelper-9.20150101-no-localized-manpages.patch
  * add debhelper-no-localized-manpages.patch
* Sun Jul 24 2016 p.drouand@gmail.com
- Update to version 9.20160709
* Sun Jan  4 2015 p.drouand@gmail.com
- Update to version 9.20150101
- Adapt debhelper-no-localized-manpages.patch to upstream changes
  * debhelper-9.20150101-no-localized-manpages.patch
- Remove upstreamed debhelper-findutils.patch
* Fri Oct  4 2013 frank.lichtenheld@sophos.com
- import upstream patch debhelper-findutils.patch from Git
  * Avoid find -perm +mode breakage caused by findutils 4.5.11,
  by instead using -perm /mode (deb#700200)
* Thu Sep 27 2012 frank.lichtenheld@sophos.com
- update to debhelper-9.20120830
  * dh_installcatalogs: Turn /etc/sgml/$package.cat into conffiles
  and introduce dependency on trigger-based sgml-base. Closes: #477751
  * dh: When there's an -indep override target without -arch, or vice versa,
  avoid acting on packages covered by the override target when running
  the command for packages not covered by it. Closes: #676462
* Fri Jul  6 2012 frank.lichtenheld@sophos.com
- fix Provides for package split, there is no /usr/bin/debhelper
- fix wrong perl require on Fedora
* Tue Jun 26 2012 frank.lichtenheld@sophos.com
- refresh debhelper-pod2man-no-utf8.patch to allow build
  on SLE 11 SP2
* Tue Jun 26 2012 frank.lichtenheld@sophos.com
- package debhelper separately
* Mon May 21 2012 i@marguerite.su
- update to dpkg-1.16.3
  * see http://packages.debian.org/changelogs/pool/main/d/dpkg/dpkg_1.16.3/changelog
- update to debhelper 9.20120518
  * Fix versioned dependency on dpkg for xz options. Closes: #672895
  * dh_link: Doc improvement. Closes: #672988
- update to devscripts-2.11.7
  * see http://packages.debian.org/changelogs/pool/main/d/devscripts/devscripts_2.11.7/changelog
- reworked patch. remove version for archtable. for it's universal.
- add dh_make 0.60
  * see http://packages.debian.org/changelogs/pool/main/d/dh-make/dh-make_0.60/changelog
- add dh_autoreconf 6
  * see http://packages.debian.org/changelogs/pool/main/d/dh-autoreconf/dh-autoreconf_6/changelog
* Thu May  3 2012 frank.lichtenheld@sophos.com
- install missing parts of devscripts
  * install man pages installed by debian/manpages
  * install symlinks installed by debian/links
* Sun Jan 29 2012 frank.lichtenheld@sophos.com
- update to dpkg-1.15.8.12
  * Do not fail to unpack shared directories missing on the file system
  from packages being replaced by other packages. Debian Bug #631808
  * Defer hardlink renames so that there's never a point were the new
  file contents are accessible from the final path before they have
  been fsync()ed and cannot be executed causing ETXTBSY when trying
  to open the to be installed paths for writing. Debian Bug #635683
  * Add armhf support to ostable and triplettable.
  Debian Bugs #594179, #639674
* Tue Dec 20 2011 coolo@suse.com
- remove call to suse_update_config (very old work around)
* Sat Nov 26 2011 frank.lichtenheld@sophos.com
- update to dpkg-1.15.8.11
  * Do not segfault on "dpkg -i --no-act".
  * Fix typo in "dpkg-name --overwrite" argument parsing so that it actually
  works at all. Ubuntu Bug #728708
  * Fix dpkg-split to not corrupt binary part metadata when generating the
  split packages on 32-bit systems.
  * Fix a regression in dpkg-divert where using --rename led to a failure when
  the rename implies crossing file systems.
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Thu Mar 31 2011 flichtenheld@astaro.com
- Merge openSUSE:Tools changes with system:packagemanager changes
* Thu Mar 17 2011 mvyskocil@suse.cz
- split the u-a to separate spec file to reduce a build cycle
* Wed Mar 16 2011 mvyskocil@suse.cz
- update to dpkg-1.15.8.10
- update to debhelper-7.5.17
- update to devscripts-2.10.71
- see /usr/share/doc/packages/deb/*/changelog for details
- build and install update-alternatives as separate subpackage
- add download urls to source tags
- remove pushd/popd madness in %%prep, use only one cd ..
- convert sed archtable hackery to patch and refresh patches
- rewrite a architecture mugging in config.h to be more readable
* Fri Jan 28 2011 adrian@suse.de
- fix build on old distros
* Fri Jan 28 2011 flichtenheld@astaro.com
- install missing debhelper files
  - install dh
  - install Debian/Debhelper/Buildsystem/*.pm
* Thu Jul 29 2010 wolfgang.rosenauer@basyskom.de
- make 'debcommit -r' work with mercurial 1.6
* Fri Apr  9 2010 puzel@novell.com
- update to dpkg-1.15.6.1
- update to debhelper-7.4.17
- update to devscripts-2.10.62
  - see /usr/share/doc/packages/deb/*/changelog for details
- split deb-devel subpackage
* Fri Feb 19 2010 puzel@novell.com
- update to dpkg-1.15.5.6
- update to debhelper-7.4.15
- update to devscripts-2.10.61
  - see /usr/share/doc/packages/deb/*/changelog for details
* Wed Jan  6 2010 jengelh@medozas.de
- enable parallel building with smp_mflags
* Fri Dec 18 2009 wr@rosenauer.org
- try to fix older dists
* Wed Nov 25 2009 puzel@novell.com
- update to dpkg-1.15.5.2, debhelper-7.4.8, devscripts-2.10.58
  - huge number of changelogs - please see appropriate changelogs
  for details:
  - /usr/share/doc/packages/deb/debhelper/changelog
  - /usr/share/doc/packages/deb/dpkg/changelog
* Thu Nov 12 2009 wr@rosenauer.org
- include devscripts-2.10.55
- add sensible-editor helper script
* Thu Aug 13 2009 puzel@novell.com
- update to debhelper-7.3.12
  * dh: Allow creation of new sequences (such as to handle a patch
    target for quilt), by adding an add_command function to the
    sequence addon interface.
  * perl_build: Fix Build check to honor source directory setting.
  * perl_build: Avoid failing if forced to be used in dh_auto_clean
    when Build does not exist (ie due to being run twice in a row).
  * dh_builddeb: Fix man page typo.
  * dh_installdeb: In udeb mode, support the menutest and isinstallable
    maintainer scripts.
* Tue Aug  4 2009 puzel@novell.com
- update to debhelper-7.3.9
  * cmake: Avoid forcing rpath off as this can break some test suites.
    It gets stripped by cmake at install time.
* Mon Jul 27 2009 puzel@novell.com
- update to debhelper-7.3.8
  * First upload of buildsystems support to unstable.
    Summary: Adds --buildsystem (modular, OO buildsystem classes),
  - -sourcedirectory, --builddirectory, and support for cmake
    and ant.
  * python_distutils buildsystem: Build for all supported Python
    versions that are installed. Ensure that correct shebangs are
    created by using `python' first during build and install.
    Also build with python*-dbg if the package build-depends
    on them.
* Thu Jul 16 2009 puzel@novell.com
- update to debhelper-7.3.4
  * Add a versioned dep on perl-base, to get a version that supports
    GetOptionsFromArray.
  * dh_install: Fix support for the case where --sourcedir=debian/tmp/foo
    is used. Perl was not being greedy enough and the 'foo' was not stripped
    from the destination directory in this unusual case.
  * dh_install: Fix support for the case where debian/tmp is
    explicitly specified in filename paths despite being searched by
    default.
  * dh_install: Add test suite covering the last 5 bugs.
* Fri Jul  3 2009 puzel@novell.com
- update to debhelper-7.3.1
  * Modular object oriented dh_auto_* buildsystem support,
    contributed by Modestas Vainius
  - dh_auto_* --sourcedirectory can now be used to specify a source
    directory if sources and/or the whole buildsystem lives elsewhere
    than the top level directory.
  - dh_auto_* --builddirectory can now be used to specify a build
    directory to use for out of source building, for build systems
    that support it.
  - dh_auto_* --buildsystem can now be used to override the autodetected
    build system, or force use of a third-party class.
  - dh_auto_* --list can be used to list available and selected build
    systems.
  - Adds support for cmake.
  - For the perl_build build system, Build is used consistently
    instead of falling back to using the generated Makefile.
  - Historical dh_auto_* behavior should be preserved despite these
    large changes..
  * Move two more command-specific options to only be accepted by the commands
    that use them. The options are:
  - -sourcedir, --destdir
    If any third-party debhelper commands use either of the above options,
    they will be broken, and need to be changed to pass options to init().
  * Make dh not complain about unknown, command-specific options passed to it,
    and further suppress warnings about such options it passes on to debhelper
    commands. This was attempted incompletely before in version 7.2.17.
  * dh_install: Fix installation of entire top-level directory
    from debian/tmp.
  * dh_install: Handle correctly the case where a glob expands to
    a dangling symlink, installing the dangling link as requested.
  * dh_install: Fix fallback use of debian/tmp in v7 mode; a bug caused
    it to put files inside a debian/tmp directory in the package build
    directory, now that prefix is stripped.
  * dh_shlibdeps: Ensure DEBIAN directory exists, as dpkg-shlibdeps
    prints a confusing warning if it does not.
  * dh_auto_install: Pass --install-layout=deb to setup.py
    to support python 2.6.
  * Allow command-specific options to be passed to commands
    via dh without causing other commands to emit a getopt
    warning or deprecation message.
  * dh_installinfo: No longer inserts install-info calls into
    maintainer scripts, as that is now triggerized. Adds a dependency
    via misc:Depends to handle partial upgrades. Note that while
    dh_installinfo already required that info files had a INFO-DIR-SECTION,
    the new system also requires they have START-INFO-DIR-ENTRY and
    END-INFO-DIR-ENTRY for proper registration. I assume there will be
    some mass bug filing for any packages that do not have that.
* Fri Jun 12 2009 puzel@suse.cz
- update to debhelper-7.2.16
  * dh_gconf: Add missed half of postrm fragment removal.
* Thu Jun 11 2009 puzel@suse.cz
- update to debhelper-7.2.15
  * dh_strip, dh_shlibdeps: Add support for OCaml shared libraries.
  * dh_compress: Avoid compressing .svg and .sgvz files, since these
    might be used as images on a html page, and also to avoid needing
    to special case the .svgz extension when compressing svg.
  * dh_scrollkeeper: Now a deprecated no-op.
  * dh_gconf: Remove postrm fragment that handled schema migration
    from /etc to /usr.
* Thu May 21 2009 puzel@suse.cz
- update to debhelper-7.2.14
  * dh: Avoid writing log after override_dh_clean is run.
  * dh_auto_configure: Pass --skipdeps safely via PERL_AUTOINSTALL.
  * dh_auto_configure: Revert --skipdeps change
* Wed May 13 2009 puzel@suse.cz
- update to debhelper-7.2.11
  * dh: Support --with addon,addon,...
  * dh_auto_configure: Add --skipdeps when running Makefile.PL,
    to prevent Module::Install from trying to download dependencies.
  * Support debian/foo.os files to suppliment previous debian/foo.arch
    file support.
* Mon May 11 2009 puzel@suse.cz
- update to debhelper-7.2.10
  * Close COMPAT_IN filehandle.
  * dh_auto_configure: Clarify man page re adding configure
    parameters.
  * dh_auto_configure: Pass packlist=0 when running Makefile.PL,
    in case it is a Build.PL passthru, to avoid it creating
    the .packlist file.
* Wed May  6 2009 puzel@suse.cz
- update to debhelper-7.2.9
  * dh_fixperms: Ensure lintian overrides are mode 644.
  * dh_fixperms: Fix permissions of OCaml .cmxs files.
  * dh: Add --without to allow disabling sequence addons (particularly
    useful to disable the default python-support addon).
- split -lang subpackage
* Tue Apr 21 2009 puzel@suse.cz
- update to debhelper-7.2.8
  * dh_desktop: Now a deprecated no-op, since desktop-file-utils
    uses triggers.
  * Move dh sequence documentation to PROGRAMMING.
* Thu Apr 16 2009 puzel@suse.cz
- update to debhelper-7.2.7
  * fix calling the same helper for separate packages in the override of dh
    binary-indep/binary-arch
  * add --remaining-packages option
  * dh_icons: ignore gnome and hicolor themes (will be handled
    by triggers)
* Mon Apr  6 2009 puzel@suse.cz
- add a hack to detect architecture correctly (bnc#469337)
* Mon Mar 16 2009 puzel@suse.cz
- update to debhelper-7.2.6
  * examples files updated to add dh_bugfiles, remove obsolete
    dh_python
  * dh_auto_test: Support DEB_BUILD_OPTIONS=nocheck
  * set MODULEBUILDRC=/dev/null when running perl Build scripts
    to avoid ~/.modulebuildrc influencing the build
  * dh_installmenus: Revert removal of update-menus calls
* Mon Mar  9 2009 puzel@suse.cz
- update to debhelper-7.2.4
  * dh_makeshlibs: Fix --add-udeb, for real
  * dh_installmenus: Now that a triggers capable menu and dpkg are in
    stable, menu does not need to be explicitly run in maintainer
    scripts, except for packages with menu-methods files.
  * dh_installdocs: No longer add maintainer script code to call
    doc-base, as it supports triggers in stable.
  * dh_bugfiles: New program, contributed by Modestas Vainius.
  * dh: Override LC_ALL, not LANG.
  * dh_installchangelogs: Support -X to exclude automatic installation
    of specific upstream changelogs.
  * Compat level 4 is now deprecated.
  * dh_makeshlibs: Re-add --add-udeb support.
  * dh_shlibdeps: Remove --add-udeb switch (was accidentially added here).
* Thu Mar  5 2009 puzel@suse.cz
- update to debhelper-7.2.2
  * dh_installmodules: Give files in /etc/modprobe.d a .conf
    syntax, as required by new module-init-tools.
  * dh_installmodules: Add preinst and postinst code to handle
    cleanly renaming the modprobe.d files on upgrade.
  * Two updates to conffile moving code from wiki:
  - Support case where the conffile name is a substring of another
    conffile's name.
  - Support case where dpkg-query says the file is obsolete.
* Tue Mar  3 2009 puzel@suse.cz
- update to dpkg-1.15.0 and debhelper-7.2.1
  - huge number of changes, please see
    /usr/share/doc/packages/deb/dpkg/changelog and
  /usr/share/doc/packages/deb/debhelper/changelog
  for details
* Tue Jan 20 2009 puzel@suse.cz
- partially revert change from Aug 12 2008 (bnc#467332)
* Thu Dec 18 2008 puzel@suse.cz
- update debhelper to 7.1.1
  * dh_install(1): Order options alphabetically.
  * Fix some docs that refered to --srcdir rather than --sourcedir.
  * Add Vcs-Browser field.
  * Ignore unknown options in DH_OPTIONS.
* Wed Oct 29 2008 puzel@suse.cz
- update debhelper to 7.1.0
  * dh_installchangelogs: Fall back to looking for changelog files ending
    with ".txt".
  * dh_gencontrol: Ensure misc:Depends is set in substvars to avoid dpkg
    complaining about it when it's empty.
  * dh: Fix typo in example.
  * Allow individual debhelper programs to define their own special options
    by passing a hash to init(), which is later passed on the Getopt::Long.
  * Move many command-specific options to only be accepted by the command
    that uses them. Affected options are:
  - x, -r, -R, -l, -L, -m,
  - -include-conffiles, --no-restart-on-upgrade, --no-start,
  - -restart-after-upgrade, --init-script, --filename, --flavor, --autodest,
  - -libpackage, --add-udeb, --dpkg-shlibdeps-params,
  - -dpkg-gencontrol-params, --update-rcd-params, --major, --remove-d,
  - -dirs-only, --keep-debug, --version-info, --list-missing, --fail-missing,
  - -language, --until, --after, --before, --remaining, --with
  * If any third-party debhelper commands use any of the above options,
    they will be broken, and need to be changed to pass options to init().
  * To avoid breaking rules files that pass options to commands that do not
    use them, debhelper will now only warn if it encounters an unknown
    option. This will be converted back to an error later.
* Tue Sep 16 2008 mrueckert@suse.de
- do not package update-alternatives it conflicts with the required
  package update-alternatives
* Tue Sep  2 2008 prusnak@suse.cz
- updated to 1.14.21
  * lots of fixes - see ChangeLog
- enabled SELinux support [Fate#303662]
* Mon Sep  1 2008 puzel@suse.cz
- update debhelper to 7.0.17
  * dh_auto_install: Fix man page, was referring to dh_auto_clean.
  * dh_gencontrol: Drop the Homepage field from udebs. Closes debian bug #492719
  * Typo. Closes debian bug #493062
  * dh_auto_install: Improve check for MakeMaker, to avoid passing PREFIX
    if the Makefile was generated by Module::Build::Compat. Closes debian bug #496157
* Tue Aug 12 2008 puzel@suse.cz
- fix paths
  * install perl stuff to %%{perl_vendorlib}/Debian where it is
    expected by alien
* Mon Aug 11 2008 coolo@suse.de
- fix paths
* Mon Jul 21 2008 puzel@suse.cz
- update debhelper to 7.0.16
  * dh: Avoid passing --with on to subcommands. Closes debian bug #490886
  * dh_installchangelogs: When searching for changelog in v7 mode, skip
    empty files. Closes debian bug #490937
* Fri Jul 18 2008 puzel@suse.cz
- update debhelper to 7.0.15
  * dh_clean: Do not delete *-stamp files in -k mode in v7. Closes debian bug #489918
* Tue Jul  8 2008 puzel@suse.cz
- update debhelper to 7.0.14
  * load python-support sequence file first, to allow ones loaded later to disable it
* Mon Jul  7 2008 puzel@suse.cz
- update dpkg to 1.14.19
  * a lot of changes and bugfixes
  * for complete changelog see program sources or
    /usr/share/doc/packages/deb/dpkg/changelog
  * removed dpkg-gcc4.patch - compiles fine without it
  * removed dpkg-make.patch, dpkg-automake.diff, dpkg-strip.patch
  * not needed anymore because of heavy changes in the build system
  * removed dpkg_1.10.23-doc.patch - fixed in upstream
- update debhelper to 7.0.13
  * a lot of changes and bugfixes
  * for complete changelog see program sources or
    /usr/share/doc/packages/deb/debhelper/changelog
  * debhelper-no-localized-manpages.diff - do not use po4a to generate
    localized documentation
- dpkg is now built by configure/make
- debhelper is now built by make
* Thu Jul 26 2007 dmueller@suse.de
- remove config.guess dependency completely
* Tue Jul 24 2007 dmueller@suse.de
- link the config.guess from automake
* Sun Apr 22 2007 ro@suse.de
- use texlive for building
* Fri Mar 30 2007 aj@suse.de
- Adjust BuildRequires.
* Fri Aug 18 2006 aj@suse.de
- Fix build with new make.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 13 2006 schwab@suse.de
- Don't strip binaries.
* Wed Dec 21 2005 ro@suse.de
- remove unpackaged symlinks
* Thu Sep  8 2005 mjancar@suse.cz
- package missing dpkg-{architecture,scanpackages,scansources} (#106239)
* Thu May 12 2005 meissner@suse.de
- use RPM_OPT_FLAGS
* Fri Apr  8 2005 uli@suse.de
- fixed to build with GCC4
* Thu Feb 10 2005 rengelhard@suse.de
- update dpkg to 1.10.27 (just translation updates)
* Thu Jan 20 2005 ro@suse.de
- update dependency: html2txt -> html2text
* Wed Jan 12 2005 rengelha@suse.de
- update dpkg to 1.10.26
* Wed Jan  5 2005 rengelhard@suse.de
- update debhelper to 4.2.30
* Tue Jan  4 2005 rengelhard@suse.de
- update debhelper to 4.2.29
* Wed Dec 15 2004 rengelhard@suse.de
- update debhelper to 4.2.28
* Mon Dec 13 2004 rengelhard@suse.de
- update debhelper to 4.2.27
* Tue Nov 16 2004 rengelhard@suse.de
- update dpkg to 1.10.25
* Thu Nov 11 2004 rengelhard@suse.de
- update debhelper to 4.2.24
* Fri Oct 29 2004 rengelhard@suse.de
- update debhelper to 4.2.23
* Wed Oct 27 2004 rengelhard@suse.de
- update dpkg to 1.10.24
* Wed Oct 13 2004 rengelhard@suse.de
- update debhelper to 4.2.21
* Tue Sep  7 2004 ro@suse.de
- remove stuff now present in own update-alternatives package
* Thu Aug 19 2004 mcihar@suse.cz
- update debhelper to 4.2.19
- update dpkg to 1.10.23
- use sed rather than patches
- remove patches accepted in upstream
* Mon May 31 2004 mcihar@suse.cz
- update debhelper to 4.2.10
- update dpkg to 1.10.21
* Thu Mar  4 2004 mcihar@suse.cz
- no root for build
- revert to manual debhelper installation as installation using
  debhelper needs dpkg and debhelper installed
* Wed Mar  3 2004 mcihar@suse.cz
- debhelper has debian/control file, so do not install manually
- update debhelper to 4.2.4
- update dpkg to 1.10.18.1
* Tue Jan 27 2004 ro@suse.de
- debhelper has no debian/control file, so install manually
* Tue Jan 27 2004 mcihar@suse.cz
- install debhelper man pages on correct place
* Mon Jan 26 2004 mcihar@suse.cz
- updated debhelper to 4.1.88 and dpkg to 1.10.18
* Wed Aug 20 2003 mjancar@suse.cz
- require the perl version we build with
* Thu Aug  7 2003 mcihar@suse.cz
- updated debhelper to 4.1.57
* Mon Jul 28 2003 schwab@suse.de
- Fix format string.
- Fix undefined use of longjmp.
- Use perl_vendorlib.
* Wed Jun 18 2003 mcihar@suse.cz
- updated debhelper to 4.1.47 (mostly fixes in dh_python)
- included directories for translated man pages
- use find_lang
* Tue May 13 2003 mcihar@suse.cz
- updated debhelper to 4.1.43
- updated dpkg to 1.1.10
* Tue Apr  8 2003 mcihar@suse.cz
- updated debhelper to 4.1.40
- fixed problems with new coreutils
* Thu Mar  6 2003 mcihar@suse.cz
- configuration files under /etc marked as %%config
* Thu Jan 30 2003 mcihar@suse.cz
- updated debhelper to 4.1.29:
  * Added a dh_python command.
  * Various fixes.
* Wed Nov 13 2002 mcihar@suse.cz
- updated dpkg to 1.10.9, major changes:
  * Make the multiline regex have an upper bound, instead of being
    unbounded, as newer perls have a larger stack frame, which cause them
    to segfault quicker with larger inputs.
  * Fix segfault in md5sum if the file being checked doesn't exist.
  * Fix extraction of md5sum in dpkg-scanpackages.
  * Handle directories better in md5sum.
  * Fix several read pass buffer bugs, and a memleak.
  * Fix segfault when --auto-deconfigure is given.
- updated debhelper to 4.1.20, major changes:
  * typo in dh_shlibdeps(1)
  * dh_fixperms: Make sure .pm files are 0644.
  * dh_strip: detect and don't strip debug/*.so files.
  * Various improvements to debhelper(1).
  * Clarified dh_perl man page.
  * Fixed excessive escaping around terms in DH_EXCLUDE_FIND.
  * Patch from Andrew Suffield to make dh_perl understand #!/usr/bin/env perl
- included part of postinst script from debian package
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <sp> to <opensp>
- changed neededforbuild <sp-devel> to <>
* Wed Aug 28 2002 mcihar@suse.cz
- corrected requires
* Wed Aug  7 2002 mcihar@suse.cz
- updated to debhelper 4.1.3:
  * various bugfixes
  * removed /usr/doc manglement code from postinst and prerm
  * removed dh_installxaw
  * dh_installchangelogs installs debian/NEWS
- updated to dpkg 1.10.4:
  * plenty of bugfixes and new switches
  * added Large File Summit extension
  * added manpages for dpkg.cfg and dselect.cfg
  * updated translations
  * install archtable into /usr/share/dpkg/
- dpkg is now build by debian/rules not by script in spec
- removed md5sum.1 start-stop-daemon.8 install-info.8 manpages also
  for other locales (these programs are not installed)
* Tue Jun 11 2002 mcihar@suse.cz
- updated to debhelper 4.0.11 and dpkg 1.9.21
* Mon Aug 13 2001 ro@suse.de
- changed neededforbuild <sp_libs> to <sp-devel>
* Fri Jun  8 2001 cihlar@suse.cz
- fixed to compile with new autoconf
* Tue Apr 24 2001 cihlar@suse.cz
- fixed warnings on ia64
* Wed Apr 18 2001 cihlar@suse.cz
- fixed to compile
* Mon Mar  5 2001 cihlar@suse.cz
- dpkg updated to version 1.8.3.1
- debhelper updated to version 3.0.8
* Tue Dec  5 2000 schwab@suse.de
- Fix broken declaration.
* Tue Oct 31 2000 cihlar@suse.cz
- update to version 1.6.14
- bzipped sources
* Tue May 23 2000 cihlar@suse.cz
- added files in /etc and /var to %%files
* Mon May 22 2000 cihlar@suse.cz
- removed install-info and start-stop-daemon
* Mon May 15 2000 schwab@suse.de
- Fixed for ia64.
* Wed May  3 2000 cihlar@suse.cz
- package created - version 1.4.0.35 (debhelper 1.1.24)
